# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.notification_builder_api import NotificationBuilderApi


class TestNotificationBuilderApi(unittest.TestCase):
    """NotificationBuilderApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationBuilderApi()

    def tearDown(self) -> None:
        pass

    def test_notification_v1_orgs_notification_builder_context_retrieve(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_context_retrieve

        Get notification context data
        """
        pass

    def test_notification_v1_orgs_notification_builder_preview_create(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_preview_create

        Preview notification
        """
        pass

    def test_notification_v1_orgs_notification_builder_recipients_list(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_recipients_list

        Get build recipients
        """
        pass

    def test_notification_v1_orgs_notification_builder_send_create(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_send_create

        Send notification
        """
        pass

    def test_notification_v1_orgs_notification_builder_validate_source_create(self) -> None:
        """Test case for notification_v1_orgs_notification_builder_validate_source_create

        Validate notification source
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MediaTypeEnum(str, Enum):
    """
    * `video` - Video * `image` - Image * `document` - Document * `audio` - Audio * `other` - Other
    """

    """
    allowed enum values
    """
    VIDEO = 'video'
    IMAGE = 'image'
    DOCUMENT = 'document'
    AUDIO = 'audio'
    OTHER = 'other'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MediaTypeEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class Credential(BaseModel):
    """
    Credential
    """ # noqa: E501
    entity_id: StrictStr = Field(alias="entityId")
    name: Annotated[str, Field(strict=True, max_length=1000)]
    name_override: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = None
    description: Optional[StrictStr] = None
    criteria_url: StrictStr = Field(alias="criteriaUrl")
    criteria_narrative: StrictStr = Field(alias="criteriaNarrative")
    created_at: datetime = Field(alias="createdAt")
    icon_image: StrictStr = Field(alias="iconImage")
    icon_image_id: StrictInt
    background_image: StrictStr = Field(alias="backgroundImage")
    background_image_id: StrictInt
    thumbnail_image: StrictStr = Field(alias="thumbnailImage")
    thumbnail_image_id: StrictInt
    catalog_items: List[StrictStr]
    courses: List[Dict[str, StrictStr]]
    programs: StrictStr
    issuer_details: Dict[str, StrictStr] = Field(alias="issuerDetails")
    html_template: Optional[StrictStr] = None
    css_template: Optional[StrictStr] = None
    metadata: Optional[Any] = None
    credential_type: StrictStr = Field(alias="credentialType")
    expires: Dict[str, StrictInt]
    tags: Optional[Any] = None
    signatories: List[Dict[str, StrictStr]]
    signal: StrictStr
    pathways: List[Dict[str, StrictStr]]
    __properties: ClassVar[List[str]] = ["entityId", "name", "name_override", "description", "criteriaUrl", "criteriaNarrative", "createdAt", "iconImage", "icon_image_id", "backgroundImage", "background_image_id", "thumbnailImage", "thumbnail_image_id", "catalog_items", "courses", "programs", "issuerDetails", "html_template", "css_template", "metadata", "credentialType", "expires", "tags", "signatories", "signal", "pathways"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Credential from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "icon_image",
            "background_image",
            "thumbnail_image",
            "catalog_items",
            "courses",
            "programs",
            "issuer_details",
            "expires",
            "signatories",
            "pathways",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if name_override (nullable) is None
        # and model_fields_set contains the field
        if self.name_override is None and "name_override" in self.model_fields_set:
            _dict['name_override'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if html_template (nullable) is None
        # and model_fields_set contains the field
        if self.html_template is None and "html_template" in self.model_fields_set:
            _dict['html_template'] = None

        # set to None if css_template (nullable) is None
        # and model_fields_set contains the field
        if self.css_template is None and "css_template" in self.model_fields_set:
            _dict['css_template'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Credential from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "entityId": obj.get("entityId"),
            "name": obj.get("name"),
            "name_override": obj.get("name_override"),
            "description": obj.get("description"),
            "criteriaUrl": obj.get("criteriaUrl"),
            "criteriaNarrative": obj.get("criteriaNarrative"),
            "createdAt": obj.get("createdAt"),
            "iconImage": obj.get("iconImage"),
            "icon_image_id": obj.get("icon_image_id"),
            "backgroundImage": obj.get("backgroundImage"),
            "background_image_id": obj.get("background_image_id"),
            "thumbnailImage": obj.get("thumbnailImage"),
            "thumbnail_image_id": obj.get("thumbnail_image_id"),
            "catalog_items": obj.get("catalog_items"),
            "courses": obj.get("courses"),
            "programs": obj.get("programs"),
            "issuerDetails": obj.get("issuerDetails"),
            "html_template": obj.get("html_template"),
            "css_template": obj.get("css_template"),
            "metadata": obj.get("metadata"),
            "credentialType": obj.get("credentialType"),
            "expires": obj.get("expires"),
            "tags": obj.get("tags"),
            "signatories": obj.get("signatories"),
            "signal": obj.get("signal"),
            "pathways": obj.get("pathways")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.item_type_enum import ItemTypeEnum
from iblai.models.media_type_enum import MediaTypeEnum
from typing import Optional, Set
from typing_extensions import Self

class MediaResource(BaseModel):
    """
    MediaResource
    """ # noqa: E501
    id: StrictInt
    title: Annotated[str, Field(strict=True, max_length=255)] = Field(description="Title of the media resource")
    description: Optional[StrictStr] = Field(default=None, description="Description of the media resource")
    media_type: MediaTypeEnum = Field(description="Type of media  * `video` - Video * `image` - Image * `document` - Document * `audio` - Audio * `other` - Other")
    item_type: ItemTypeEnum = Field(description="Type of item this media is associated with  * `course` - Course * `unit` - Unit * `resource` - Resource * `course_unit` - Course and Unit * `course_resource` - Course and Resource * `unit_resource` - Unit and Resource * `all` - Course, Unit, and Resource")
    course_id: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="ID of the associated course")
    unit_id: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="ID of the associated unit")
    item_id: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="ID of the associated item (resource)")
    platform: StrictInt = Field(description="The platform this media resource belongs to")
    file_url: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, description="External URL for the media resource")
    file: Optional[StrictStr] = Field(default=None, description="Uploaded media file")
    created_by: Optional[StrictInt] = Field(description="User who created this media resource")
    created_at: datetime = Field(description="When this record was created")
    updated_at: datetime = Field(description="When this record was last updated")
    __properties: ClassVar[List[str]] = ["id", "title", "description", "media_type", "item_type", "course_id", "unit_id", "item_id", "platform", "file_url", "file", "created_by", "created_at", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MediaResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "item_type",
            "platform",
            "created_by",
            "created_at",
            "updated_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if course_id (nullable) is None
        # and model_fields_set contains the field
        if self.course_id is None and "course_id" in self.model_fields_set:
            _dict['course_id'] = None

        # set to None if unit_id (nullable) is None
        # and model_fields_set contains the field
        if self.unit_id is None and "unit_id" in self.model_fields_set:
            _dict['unit_id'] = None

        # set to None if item_id (nullable) is None
        # and model_fields_set contains the field
        if self.item_id is None and "item_id" in self.model_fields_set:
            _dict['item_id'] = None

        # set to None if file_url (nullable) is None
        # and model_fields_set contains the field
        if self.file_url is None and "file_url" in self.model_fields_set:
            _dict['file_url'] = None

        # set to None if file (nullable) is None
        # and model_fields_set contains the field
        if self.file is None and "file" in self.model_fields_set:
            _dict['file'] = None

        # set to None if created_by (nullable) is None
        # and model_fields_set contains the field
        if self.created_by is None and "created_by" in self.model_fields_set:
            _dict['created_by'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MediaResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "description": obj.get("description"),
            "media_type": obj.get("media_type"),
            "item_type": obj.get("item_type"),
            "course_id": obj.get("course_id"),
            "unit_id": obj.get("unit_id"),
            "item_id": obj.get("item_id"),
            "platform": obj.get("platform"),
            "file_url": obj.get("file_url"),
            "file": obj.get("file"),
            "created_by": obj.get("created_by"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from iblai.models.observation import Observation
from typing import Optional, Set
from typing_extensions import Self

class Trace(BaseModel):
    """
    Trace
    """ # noqa: E501
    id: StrictStr
    username: Optional[StrictStr] = None
    external_id: Optional[StrictStr] = Field(alias="externalId")
    timestamp: datetime
    name: StrictStr
    totalprice: Union[StrictFloat, StrictInt]
    user_id: Optional[StrictStr] = Field(alias="userId")
    metadata: Optional[Dict[str, Any]]
    release: Optional[StrictStr]
    version: Optional[StrictStr]
    project_id: StrictStr = Field(alias="projectId")
    public: StrictBool
    bookmarked: StrictBool
    tags: List[StrictStr]
    input: Optional[Any]
    output: Optional[Any]
    session_id: Optional[StrictStr] = Field(alias="sessionId")
    scores: List[Dict[str, Any]]
    observations: List[Observation]
    __properties: ClassVar[List[str]] = ["id", "username", "externalId", "timestamp", "name", "totalprice", "userId", "metadata", "release", "version", "projectId", "public", "bookmarked", "tags", "input", "output", "sessionId", "scores", "observations"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Trace from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in observations (list)
        _items = []
        if self.observations:
            for _item in self.observations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['observations'] = _items
        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if external_id (nullable) is None
        # and model_fields_set contains the field
        if self.external_id is None and "external_id" in self.model_fields_set:
            _dict['externalId'] = None

        # set to None if user_id (nullable) is None
        # and model_fields_set contains the field
        if self.user_id is None and "user_id" in self.model_fields_set:
            _dict['userId'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if release (nullable) is None
        # and model_fields_set contains the field
        if self.release is None and "release" in self.model_fields_set:
            _dict['release'] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        # set to None if input (nullable) is None
        # and model_fields_set contains the field
        if self.input is None and "input" in self.model_fields_set:
            _dict['input'] = None

        # set to None if output (nullable) is None
        # and model_fields_set contains the field
        if self.output is None and "output" in self.model_fields_set:
            _dict['output'] = None

        # set to None if session_id (nullable) is None
        # and model_fields_set contains the field
        if self.session_id is None and "session_id" in self.model_fields_set:
            _dict['sessionId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Trace from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "username": obj.get("username"),
            "externalId": obj.get("externalId"),
            "timestamp": obj.get("timestamp"),
            "name": obj.get("name"),
            "totalprice": obj.get("totalprice"),
            "userId": obj.get("userId"),
            "metadata": obj.get("metadata"),
            "release": obj.get("release"),
            "version": obj.get("version"),
            "projectId": obj.get("projectId"),
            "public": obj.get("public"),
            "bookmarked": obj.get("bookmarked"),
            "tags": obj.get("tags"),
            "input": obj.get("input"),
            "output": obj.get("output"),
            "sessionId": obj.get("sessionId"),
            "scores": obj.get("scores"),
            "observations": [Observation.from_dict(_item) for _item in obj["observations"]] if obj.get("observations") is not None else None
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_analytics_api import AiAnalyticsApi


class TestAiAnalyticsApi(unittest.TestCase):
    """AiAnalyticsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiAnalyticsApi()

    def tearDown(self) -> None:
        pass

    def test_ai_analytics_orgs_users_chat_history_filter_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_chat_history_filter_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_chat_history_list(self) -> None:
        """Test case for ai_analytics_orgs_users_chat_history_list

        """
        pass

    def test_ai_analytics_orgs_users_chat_history_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_chat_history_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_conversation_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_conversation_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_costs_model_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_costs_model_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_costs_model_usage_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_costs_model_usage_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_costs_permentor_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_costs_permentor_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_costs_peruser_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_costs_peruser_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_mentor_detail_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_mentor_detail_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_mentor_summary_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_mentor_summary_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_sentiment_count_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_sentiment_count_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_topics_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_topics_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_topics_summary_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_topics_summary_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_traces_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_traces_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_traces_retrieve2(self) -> None:
        """Test case for ai_analytics_orgs_users_traces_retrieve2

        """
        pass

    def test_ai_analytics_orgs_users_traces_scores_create(self) -> None:
        """Test case for ai_analytics_orgs_users_traces_scores_create

        """
        pass

    def test_ai_analytics_orgs_users_traces_scores_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_traces_scores_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_transcripts_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_transcripts_retrieve

        """
        pass

    def test_ai_analytics_orgs_users_user_feedback_retrieve(self) -> None:
        """Test case for ai_analytics_orgs_users_user_feedback_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.mentor import Mentor
from iblai.models.periodic_task import PeriodicTask
from iblai.models.previous_agent_status_enum import PreviousAgentStatusEnum
from typing import Optional, Set
from typing_extensions import Self

class PeriodicAgent(BaseModel):
    """
    PeriodicAgent
    """ # noqa: E501
    id: StrictInt
    mentor: Mentor
    title: Annotated[str, Field(strict=True, max_length=255)]
    username: StrictStr
    description: Optional[StrictStr] = None
    prompt: Optional[StrictStr] = Field(default=None, description="Prompt for the periodic agent if any.")
    task: PeriodicTask
    created_at: datetime
    modified_at: datetime
    enabled: StrictBool
    one_off: StrictBool
    platform_key: StrictStr
    pathway: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    callback_url: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    callback_secret: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    parent_session_id: Optional[Annotated[str, Field(strict=True, max_length=200)]] = None
    parent_mentor_id: Optional[StrictInt] = None
    previous_agent: Optional[StrictInt] = Field(default=None, description="Agent that needs to run before the current agent runs.")
    previous_agent_status: Optional[PreviousAgentStatusEnum] = Field(default=None, description="The status that the previous agent must be in before this agent gets scheduled.  * `success` - Success * `error` - Error * `running` - Running * `pending` - Pending")
    previous_agent_output: StrictStr = Field(description="This will be fed into the run of this agent as part of its input prompt.")
    __properties: ClassVar[List[str]] = ["id", "mentor", "title", "username", "description", "prompt", "task", "created_at", "modified_at", "enabled", "one_off", "platform_key", "pathway", "callback_url", "callback_secret", "parent_session_id", "parent_mentor_id", "previous_agent", "previous_agent_status", "previous_agent_output"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PeriodicAgent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "username",
            "created_at",
            "modified_at",
            "enabled",
            "one_off",
            "platform_key",
            "previous_agent_output",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of mentor
        if self.mentor:
            _dict['mentor'] = self.mentor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of task
        if self.task:
            _dict['task'] = self.task.to_dict()
        # set to None if parent_mentor_id (nullable) is None
        # and model_fields_set contains the field
        if self.parent_mentor_id is None and "parent_mentor_id" in self.model_fields_set:
            _dict['parent_mentor_id'] = None

        # set to None if previous_agent (nullable) is None
        # and model_fields_set contains the field
        if self.previous_agent is None and "previous_agent" in self.model_fields_set:
            _dict['previous_agent'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PeriodicAgent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "mentor": Mentor.from_dict(obj["mentor"]) if obj.get("mentor") is not None else None,
            "title": obj.get("title"),
            "username": obj.get("username"),
            "description": obj.get("description"),
            "prompt": obj.get("prompt"),
            "task": PeriodicTask.from_dict(obj["task"]) if obj.get("task") is not None else None,
            "created_at": obj.get("created_at"),
            "modified_at": obj.get("modified_at"),
            "enabled": obj.get("enabled"),
            "one_off": obj.get("one_off"),
            "platform_key": obj.get("platform_key"),
            "pathway": obj.get("pathway"),
            "callback_url": obj.get("callback_url"),
            "callback_secret": obj.get("callback_secret"),
            "parent_session_id": obj.get("parent_session_id"),
            "parent_mentor_id": obj.get("parent_mentor_id"),
            "previous_agent": obj.get("previous_agent"),
            "previous_agent_status": obj.get("previous_agent_status"),
            "previous_agent_output": obj.get("previous_agent_output")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.resource_create_update import ResourceCreateUpdate

class TestResourceCreateUpdate(unittest.TestCase):
    """ResourceCreateUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceCreateUpdate:
        """Test ResourceCreateUpdate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceCreateUpdate`
        """
        model = ResourceCreateUpdate()
        if include_optional:
            return ResourceCreateUpdate(
                id = 56,
                user_id = 56,
                username = '',
                resource_type = '',
                url = '',
                name = '',
                description = '',
                skills = [
                    ''
                    ],
                image = '',
                data = None
            )
        else:
            return ResourceCreateUpdate(
                resource_type = '',
                url = '',
                name = '',
        )
        """

    def testResourceCreateUpdate(self):
        """Test ResourceCreateUpdate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from iblai.models.data_set import DataSet
from iblai.models.data_set_create import DataSetCreate
from iblai.models.paginated_data_set_list import PaginatedDataSetList
from iblai.models.paginated_training_list import PaginatedTrainingList
from iblai.models.patched_data_set import PatchedDataSet
from iblai.models.patched_training_create import PatchedTrainingCreate
from iblai.models.training import Training
from iblai.models.training_create import TrainingCreate

from iblai.api_client import ApiClient, RequestSerialized
from iblai.api_response import ApiResponse
from iblai.rest import RESTResponseType


class AiFinetuningApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def ai_finetuning_v1_org_user_datasets_create(
        self,
        org: StrictStr,
        username: StrictStr,
        data_set_create: DataSetCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_datasets_create

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param data_set_create: (required)
        :type data_set_create: DataSetCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_datasets_create_serialize(
            org=org,
            username=username,
            data_set_create=data_set_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "DataSetCreate",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_datasets_create_serialize(
        self,
        org,
        username,
        data_set_create,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if data_set_create is not None:
            _body_params = data_set_create


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/datasets/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_datasets_destroy(
        self,
        id: Annotated[StrictStr, Field(description="A UUID string identifying this data set.")],
        org: StrictStr,
        username: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_datasets_destroy

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param id: A UUID string identifying this data set. (required)
        :type id: str
        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_datasets_destroy_serialize(
            id=id,
            org=org,
            username=username,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_datasets_destroy_serialize(
        self,
        id,
        org,
        username,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/datasets/{id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_datasets_list(
        self,
        org: StrictStr,
        username: StrictStr,
        date_created: Optional[datetime] = None,
        num_data_points: Optional[StrictInt] = None,
        ordering: Annotated[Optional[StrictStr], Field(description="Which field to use when ordering the results.")] = None,
        page: Annotated[Optional[StrictInt], Field(description="A page number within the paginated result set.")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        retry_attempts: Optional[StrictInt] = None,
        search: Annotated[Optional[StrictStr], Field(description="A search term.")] = None,
        status: Annotated[Optional[StrictStr], Field(description="* `pending` - Pending * `processing` - Processing * `completed` - Completed * `failed` - Failed")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_datasets_list

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param date_created:
        :type date_created: datetime
        :param num_data_points:
        :type num_data_points: int
        :param ordering: Which field to use when ordering the results.
        :type ordering: str
        :param page: A page number within the paginated result set.
        :type page: int
        :param page_size: Number of results to return per page.
        :type page_size: int
        :param retry_attempts:
        :type retry_attempts: int
        :param search: A search term.
        :type search: str
        :param status: * `pending` - Pending * `processing` - Processing * `completed` - Completed * `failed` - Failed
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_datasets_list_serialize(
            org=org,
            username=username,
            date_created=date_created,
            num_data_points=num_data_points,
            ordering=ordering,
            page=page,
            page_size=page_size,
            retry_attempts=retry_attempts,
            search=search,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedDataSetList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_datasets_list_serialize(
        self,
        org,
        username,
        date_created,
        num_data_points,
        ordering,
        page,
        page_size,
        retry_attempts,
        search,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        if date_created is not None:
            if isinstance(date_created, datetime):
                _query_params.append(
                    (
                        'date_created',
                        date_created.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('date_created', date_created))
            
        if num_data_points is not None:
            
            _query_params.append(('num_data_points', num_data_points))
            
        if ordering is not None:
            
            _query_params.append(('ordering', ordering))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        if retry_attempts is not None:
            
            _query_params.append(('retry_attempts', retry_attempts))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/datasets/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_datasets_partial_update(
        self,
        id: Annotated[StrictStr, Field(description="A UUID string identifying this data set.")],
        org: StrictStr,
        username: StrictStr,
        patched_data_set: Optional[PatchedDataSet] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_datasets_partial_update

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param id: A UUID string identifying this data set. (required)
        :type id: str
        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param patched_data_set:
        :type patched_data_set: PatchedDataSet
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_datasets_partial_update_serialize(
            id=id,
            org=org,
            username=username,
            patched_data_set=patched_data_set,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DataSet",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_datasets_partial_update_serialize(
        self,
        id,
        org,
        username,
        patched_data_set,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if patched_data_set is not None:
            _body_params = patched_data_set


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/datasets/{id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_datasets_retrieve(
        self,
        id: Annotated[StrictStr, Field(description="A UUID string identifying this data set.")],
        org: StrictStr,
        username: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_datasets_retrieve

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param id: A UUID string identifying this data set. (required)
        :type id: str
        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_datasets_retrieve_serialize(
            id=id,
            org=org,
            username=username,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DataSet",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_datasets_retrieve_serialize(
        self,
        id,
        org,
        username,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/datasets/{id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_datasets_update(
        self,
        id: Annotated[StrictStr, Field(description="A UUID string identifying this data set.")],
        org: StrictStr,
        username: StrictStr,
        data_set: DataSet,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_datasets_update

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param id: A UUID string identifying this data set. (required)
        :type id: str
        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param data_set: (required)
        :type data_set: DataSet
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_datasets_update_serialize(
            id=id,
            org=org,
            username=username,
            data_set=data_set,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DataSet",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_datasets_update_serialize(
        self,
        id,
        org,
        username,
        data_set,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if data_set is not None:
            _body_params = data_set


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/datasets/{id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_trainings_create(
        self,
        org: StrictStr,
        username: StrictStr,
        training_create: TrainingCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_trainings_create

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param training_create: (required)
        :type training_create: TrainingCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_trainings_create_serialize(
            org=org,
            username=username,
            training_create=training_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "TrainingCreate",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_trainings_create_serialize(
        self,
        org,
        username,
        training_create,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if training_create is not None:
            _body_params = training_create


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/trainings/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_trainings_destroy(
        self,
        id: Annotated[StrictStr, Field(description="A UUID string identifying this training.")],
        org: StrictStr,
        username: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_trainings_destroy

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param id: A UUID string identifying this training. (required)
        :type id: str
        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_trainings_destroy_serialize(
            id=id,
            org=org,
            username=username,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_trainings_destroy_serialize(
        self,
        id,
        org,
        username,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/trainings/{id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_trainings_finetuned_models_retrieve(
        self,
        org: StrictStr,
        username: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_trainings_finetuned_models_retrieve

        Retrieves a paginated list of completed fine-tuned models, excluding those without a fine-tuned model. Filtering and pagination is allowed.  NB: This is only a helper endpoint. The same functionality can be achieved with the appropriate filters using the     training list endpoint. Returns:     Response: A paginated response containing the serialized fine-tuned models.

        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_trainings_finetuned_models_retrieve_serialize(
            org=org,
            username=username,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Training",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_trainings_finetuned_models_retrieve_serialize(
        self,
        org,
        username,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/trainings/finetuned-models/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_trainings_list(
        self,
        org: StrictStr,
        username: StrictStr,
        base_model_name: Optional[StrictStr] = None,
        dataset: Optional[StrictStr] = None,
        date_created: Optional[datetime] = None,
        fine_tuned_model: Optional[StrictStr] = None,
        last_modified: Optional[datetime] = None,
        ordering: Annotated[Optional[StrictStr], Field(description="Which field to use when ordering the results.")] = None,
        page: Annotated[Optional[StrictInt], Field(description="A page number within the paginated result set.")] = None,
        page_size: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        preprocess_dataset: Optional[StrictBool] = None,
        provider: Annotated[Optional[StrictStr], Field(description="* `openai` - Openai")] = None,
        search: Annotated[Optional[StrictStr], Field(description="A search term.")] = None,
        status: Annotated[Optional[StrictStr], Field(description="* `pending` - Pending * `processing` - Processing * `completed` - Completed * `cancelled` - Cancelled * `failed` - Failed")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_trainings_list

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param base_model_name:
        :type base_model_name: str
        :param dataset:
        :type dataset: str
        :param date_created:
        :type date_created: datetime
        :param fine_tuned_model:
        :type fine_tuned_model: str
        :param last_modified:
        :type last_modified: datetime
        :param ordering: Which field to use when ordering the results.
        :type ordering: str
        :param page: A page number within the paginated result set.
        :type page: int
        :param page_size: Number of results to return per page.
        :type page_size: int
        :param preprocess_dataset:
        :type preprocess_dataset: bool
        :param provider: * `openai` - Openai
        :type provider: str
        :param search: A search term.
        :type search: str
        :param status: * `pending` - Pending * `processing` - Processing * `completed` - Completed * `cancelled` - Cancelled * `failed` - Failed
        :type status: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_trainings_list_serialize(
            org=org,
            username=username,
            base_model_name=base_model_name,
            dataset=dataset,
            date_created=date_created,
            fine_tuned_model=fine_tuned_model,
            last_modified=last_modified,
            ordering=ordering,
            page=page,
            page_size=page_size,
            preprocess_dataset=preprocess_dataset,
            provider=provider,
            search=search,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedTrainingList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_trainings_list_serialize(
        self,
        org,
        username,
        base_model_name,
        dataset,
        date_created,
        fine_tuned_model,
        last_modified,
        ordering,
        page,
        page_size,
        preprocess_dataset,
        provider,
        search,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        if base_model_name is not None:
            
            _query_params.append(('base_model_name', base_model_name))
            
        if dataset is not None:
            
            _query_params.append(('dataset', dataset))
            
        if date_created is not None:
            if isinstance(date_created, datetime):
                _query_params.append(
                    (
                        'date_created',
                        date_created.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('date_created', date_created))
            
        if fine_tuned_model is not None:
            
            _query_params.append(('fine_tuned_model', fine_tuned_model))
            
        if last_modified is not None:
            if isinstance(last_modified, datetime):
                _query_params.append(
                    (
                        'last_modified',
                        last_modified.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('last_modified', last_modified))
            
        if ordering is not None:
            
            _query_params.append(('ordering', ordering))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        if preprocess_dataset is not None:
            
            _query_params.append(('preprocess_dataset', preprocess_dataset))
            
        if provider is not None:
            
            _query_params.append(('provider', provider))
            
        if search is not None:
            
            _query_params.append(('search', search))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/trainings/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_trainings_partial_update(
        self,
        id: Annotated[StrictStr, Field(description="A UUID string identifying this training.")],
        org: StrictStr,
        username: StrictStr,
        patched_training_create: Optional[PatchedTrainingCreate] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_trainings_partial_update

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param id: A UUID string identifying this training. (required)
        :type id: str
        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param patched_training_create:
        :type patched_training_create: PatchedTrainingCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_trainings_partial_update_serialize(
            id=id,
            org=org,
            username=username,
            patched_training_create=patched_training_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TrainingCreate",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_trainings_partial_update_serialize(
        self,
        id,
        org,
        username,
        patched_training_create,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if patched_training_create is not None:
            _body_params = patched_training_create


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/trainings/{id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_trainings_retrieve(
        self,
        id: Annotated[StrictStr, Field(description="A UUID string identifying this training.")],
        org: StrictStr,
        username: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_trainings_retrieve

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param id: A UUID string identifying this training. (required)
        :type id: str
        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_trainings_retrieve_serialize(
            id=id,
            org=org,
            username=username,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Training",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_trainings_retrieve_serialize(
        self,
        id,
        org,
        username,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/trainings/{id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_finetuning_v1_org_user_trainings_update(
        self,
        id: Annotated[StrictStr, Field(description="A UUID string identifying this training.")],
        org: StrictStr,
        username: StrictStr,
        training_create: TrainingCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_finetuning_v1_org_user_trainings_update

        Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin

        :param id: A UUID string identifying this training. (required)
        :type id: str
        :param org: (required)
        :type org: str
        :param username: (required)
        :type username: str
        :param training_create: (required)
        :type training_create: TrainingCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_finetuning_v1_org_user_trainings_update_serialize(
            id=id,
            org=org,
            username=username,
            training_create=training_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TrainingCreate",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_finetuning_v1_org_user_trainings_update_serialize(
        self,
        id,
        org,
        username,
        training_create,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if org is not None:
            _path_params['org'] = org
        if username is not None:
            _path_params['username'] = username
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if training_create is not None:
            _body_params = training_create


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/ai-finetuning/v1/org/{org}/user/{username}/trainings/{id}/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.patched_prompt import PatchedPrompt

class TestPatchedPrompt(unittest.TestCase):
    """PatchedPrompt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedPrompt:
        """Test PatchedPrompt
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedPrompt`
        """
        model = PatchedPrompt()
        if include_optional:
            return PatchedPrompt(
                id = 56,
                mentor = '',
                tone = '',
                style = '',
                language = '',
                tags = [
                    56
                    ],
                is_system = True,
                metadata = None,
                category = '',
                prompt = '',
                title = '',
                description = '',
                prompt_visibility = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = '',
                platform = 56
            )
        else:
            return PatchedPrompt(
        )
        """

    def testPatchedPrompt(self):
        """Test PatchedPrompt"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from iblai.models.call_configuration_mode_enum import CallConfigurationModeEnum
from iblai.models.llm_provider_enum import LlmProviderEnum
from iblai.models.stt_provider_enum import SttProviderEnum
from iblai.models.tts_provider_enum import TtsProviderEnum
from iblai.models.voice import Voice
from typing import Optional, Set
from typing_extensions import Self

class CallConfiguration(BaseModel):
    """
    CallConfiguration
    """ # noqa: E501
    id: StrictInt
    mentor: StrictInt
    mode: Optional[CallConfigurationModeEnum] = None
    tts_provider: Optional[TtsProviderEnum] = None
    stt_provider: Optional[SttProviderEnum] = None
    llm_provider: Optional[LlmProviderEnum] = None
    use_function_calling_for_rag: Optional[StrictBool] = Field(default=None, description="Whether to use function calls in the agent or force RAG calls before LLM generation")
    google_voice: Optional[Voice] = None
    openai_voice: Optional[Voice] = None
    openai_voice_id: Optional[StrictInt]
    google_voice_id: Optional[StrictInt]
    enable_video: Optional[StrictBool] = Field(default=None, description="Whether to enable video for the call. (applicable only for realtime mode)")
    platform_key: StrictStr
    __properties: ClassVar[List[str]] = ["id", "mentor", "mode", "tts_provider", "stt_provider", "llm_provider", "use_function_calling_for_rag", "google_voice", "openai_voice", "openai_voice_id", "google_voice_id", "enable_video", "platform_key"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CallConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "platform_key",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of google_voice
        if self.google_voice:
            _dict['google_voice'] = self.google_voice.to_dict()
        # override the default output from pydantic by calling `to_dict()` of openai_voice
        if self.openai_voice:
            _dict['openai_voice'] = self.openai_voice.to_dict()
        # set to None if openai_voice_id (nullable) is None
        # and model_fields_set contains the field
        if self.openai_voice_id is None and "openai_voice_id" in self.model_fields_set:
            _dict['openai_voice_id'] = None

        # set to None if google_voice_id (nullable) is None
        # and model_fields_set contains the field
        if self.google_voice_id is None and "google_voice_id" in self.model_fields_set:
            _dict['google_voice_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CallConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "mentor": obj.get("mentor"),
            "mode": obj.get("mode"),
            "tts_provider": obj.get("tts_provider"),
            "stt_provider": obj.get("stt_provider"),
            "llm_provider": obj.get("llm_provider"),
            "use_function_calling_for_rag": obj.get("use_function_calling_for_rag"),
            "google_voice": Voice.from_dict(obj["google_voice"]) if obj.get("google_voice") is not None else None,
            "openai_voice": Voice.from_dict(obj["openai_voice"]) if obj.get("openai_voice") is not None else None,
            "openai_voice_id": obj.get("openai_voice_id"),
            "google_voice_id": obj.get("google_voice_id"),
            "enable_video": obj.get("enable_video"),
            "platform_key": obj.get("platform_key")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class EmailPromptList(BaseModel):
    """
    EmailPromptList
    """ # noqa: E501
    id: StrictInt
    sender_email: Annotated[str, Field(strict=True, max_length=254)]
    sender_name: Optional[StrictStr] = None
    subject: Optional[StrictStr] = None
    content_summary: Optional[StrictStr]
    mentor_name: Optional[StrictStr] = None
    mentor_email: Annotated[str, Field(strict=True, max_length=254)]
    is_processed: Optional[StrictBool] = None
    inserted_at: StrictStr
    __properties: ClassVar[List[str]] = ["id", "sender_email", "sender_name", "subject", "content_summary", "mentor_name", "mentor_email", "is_processed", "inserted_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EmailPromptList from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "content_summary",
            "inserted_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if sender_name (nullable) is None
        # and model_fields_set contains the field
        if self.sender_name is None and "sender_name" in self.model_fields_set:
            _dict['sender_name'] = None

        # set to None if subject (nullable) is None
        # and model_fields_set contains the field
        if self.subject is None and "subject" in self.model_fields_set:
            _dict['subject'] = None

        # set to None if content_summary (nullable) is None
        # and model_fields_set contains the field
        if self.content_summary is None and "content_summary" in self.model_fields_set:
            _dict['content_summary'] = None

        # set to None if mentor_name (nullable) is None
        # and model_fields_set contains the field
        if self.mentor_name is None and "mentor_name" in self.model_fields_set:
            _dict['mentor_name'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EmailPromptList from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "sender_email": obj.get("sender_email"),
            "sender_name": obj.get("sender_name"),
            "subject": obj.get("subject"),
            "content_summary": obj.get("content_summary"),
            "mentor_name": obj.get("mentor_name"),
            "mentor_email": obj.get("mentor_email"),
            "is_processed": obj.get("is_processed"),
            "inserted_at": obj.get("inserted_at")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from iblai.models.data_set_platform_value import DataSetPlatformValue
from iblai.models.data_set_status_enum import DataSetStatusEnum
from typing import Optional, Set
from typing_extensions import Self

class DataSet(BaseModel):
    """
    DataSet
    """ # noqa: E501
    id: StrictStr
    platform: Optional[Dict[str, DataSetPlatformValue]]
    name: Annotated[str, Field(strict=True, max_length=255)]
    prompt: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, description="(if any) Special instructions for generating the dataset. This could be requirements on tone, language, style, etc.")
    source_url: Optional[Annotated[str, Field(strict=True, max_length=400)]] = None
    source_file: Optional[StrictStr] = None
    status: Optional[DataSetStatusEnum] = None
    num_data_points: Optional[StrictInt] = None
    train_split: Optional[Union[Annotated[float, Field(le=1, strict=True, ge=0)], Annotated[int, Field(le=1, strict=True, ge=0)]]] = None
    train_file: Optional[StrictStr] = None
    test_file: Optional[StrictStr] = None
    retry_attempts: Optional[StrictInt] = None
    error_log: Optional[StrictStr] = None
    date_created: datetime
    last_modified: datetime
    __properties: ClassVar[List[str]] = ["id", "platform", "name", "prompt", "source_url", "source_file", "status", "num_data_points", "train_split", "train_file", "test_file", "retry_attempts", "error_log", "date_created", "last_modified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataSet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "platform",
            "date_created",
            "last_modified",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in platform (dict)
        _field_dict = {}
        if self.platform:
            for _key in self.platform:
                if self.platform[_key]:
                    _field_dict[_key] = self.platform[_key].to_dict()
            _dict['platform'] = _field_dict
        # set to None if platform (nullable) is None
        # and model_fields_set contains the field
        if self.platform is None and "platform" in self.model_fields_set:
            _dict['platform'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataSet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "platform": dict(
                (_k, DataSetPlatformValue.from_dict(_v))
                for _k, _v in obj["platform"].items()
            )
            if obj.get("platform") is not None
            else None,
            "name": obj.get("name"),
            "prompt": obj.get("prompt"),
            "source_url": obj.get("source_url"),
            "source_file": obj.get("source_file"),
            "status": obj.get("status"),
            "num_data_points": obj.get("num_data_points"),
            "train_split": obj.get("train_split"),
            "train_file": obj.get("train_file"),
            "test_file": obj.get("test_file"),
            "retry_attempts": obj.get("retry_attempts"),
            "error_log": obj.get("error_log"),
            "date_created": obj.get("date_created"),
            "last_modified": obj.get("last_modified")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_prompt_api import AiPromptApi


class TestAiPromptApi(unittest.TestCase):
    """AiPromptApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiPromptApi()

    def tearDown(self) -> None:
        pass

    def test_ai_prompt_orgs_metadata_create(self) -> None:
        """Test case for ai_prompt_orgs_metadata_create

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_create(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_create

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_destroy

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_destroy2(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_destroy2

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_update(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_update

        """
        pass

    def test_ai_prompt_orgs_users_all_chats_memory_update2(self) -> None:
        """Test case for ai_prompt_orgs_users_all_chats_memory_update2

        """
        pass

    def test_ai_prompt_orgs_users_chat_memory_status_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_chat_memory_status_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_chat_memory_status_update(self) -> None:
        """Test case for ai_prompt_orgs_users_chat_memory_status_update

        """
        pass

    def test_ai_prompt_orgs_users_languages_create(self) -> None:
        """Test case for ai_prompt_orgs_users_languages_create

        """
        pass

    def test_ai_prompt_orgs_users_languages_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_languages_destroy

        """
        pass

    def test_ai_prompt_orgs_users_languages_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_languages_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_languages_update(self) -> None:
        """Test case for ai_prompt_orgs_users_languages_update

        """
        pass

    def test_ai_prompt_orgs_users_memory_context_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_context_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_memory_context_update(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_context_update

        """
        pass

    def test_ai_prompt_orgs_users_memory_create(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_create

        """
        pass

    def test_ai_prompt_orgs_users_memory_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_destroy

        """
        pass

    def test_ai_prompt_orgs_users_memory_destroy2(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_destroy2

        """
        pass

    def test_ai_prompt_orgs_users_memory_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_memory_status_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_status_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_memory_status_update(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_status_update

        """
        pass

    def test_ai_prompt_orgs_users_memory_update(self) -> None:
        """Test case for ai_prompt_orgs_users_memory_update

        """
        pass

    def test_ai_prompt_orgs_users_metadata_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_metadata_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_prompt_create(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_create

        """
        pass

    def test_ai_prompt_orgs_users_prompt_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_destroy

        """
        pass

    def test_ai_prompt_orgs_users_prompt_list(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_list

        """
        pass

    def test_ai_prompt_orgs_users_prompt_partial_update(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_partial_update

        """
        pass

    def test_ai_prompt_orgs_users_prompt_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_prompt_update(self) -> None:
        """Test case for ai_prompt_orgs_users_prompt_update

        """
        pass

    def test_ai_prompt_orgs_users_prompts_category_create(self) -> None:
        """Test case for ai_prompt_orgs_users_prompts_category_create

        """
        pass

    def test_ai_prompt_orgs_users_prompts_category_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_prompts_category_destroy

        """
        pass

    def test_ai_prompt_orgs_users_prompts_category_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_prompts_category_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_sessions_guided_prompts_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_sessions_guided_prompts_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_styles_create(self) -> None:
        """Test case for ai_prompt_orgs_users_styles_create

        """
        pass

    def test_ai_prompt_orgs_users_styles_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_styles_destroy

        """
        pass

    def test_ai_prompt_orgs_users_styles_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_styles_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_styles_update(self) -> None:
        """Test case for ai_prompt_orgs_users_styles_update

        """
        pass

    def test_ai_prompt_orgs_users_tags_create(self) -> None:
        """Test case for ai_prompt_orgs_users_tags_create

        """
        pass

    def test_ai_prompt_orgs_users_tags_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_tags_destroy

        """
        pass

    def test_ai_prompt_orgs_users_tags_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_tags_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_tags_update(self) -> None:
        """Test case for ai_prompt_orgs_users_tags_update

        """
        pass

    def test_ai_prompt_orgs_users_tones_create(self) -> None:
        """Test case for ai_prompt_orgs_users_tones_create

        """
        pass

    def test_ai_prompt_orgs_users_tones_destroy(self) -> None:
        """Test case for ai_prompt_orgs_users_tones_destroy

        """
        pass

    def test_ai_prompt_orgs_users_tones_retrieve(self) -> None:
        """Test case for ai_prompt_orgs_users_tones_retrieve

        """
        pass

    def test_ai_prompt_orgs_users_tones_update(self) -> None:
        """Test case for ai_prompt_orgs_users_tones_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.platform_license_create import PlatformLicenseCreate

class TestPlatformLicenseCreate(unittest.TestCase):
    """PlatformLicenseCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlatformLicenseCreate:
        """Test PlatformLicenseCreate
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlatformLicenseCreate`
        """
        model = PlatformLicenseCreate()
        if include_optional:
            return PlatformLicenseCreate(
                platform_key = '',
                platform_org = '',
                name = '',
                count = 56,
                started = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expired = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                active = True,
                metadata = {
                    'key' : null
                    },
                source = '',
                external_id = '',
                transaction_id = '',
                change_type = 'create'
            )
        else:
            return PlatformLicenseCreate(
                platform_key = '',
        )
        """

    def testPlatformLicenseCreate(self):
        """Test PlatformLicenseCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.mcp_server import MCPServer

class TestMCPServer(unittest.TestCase):
    """MCPServer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MCPServer:
        """Test MCPServer
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MCPServer`
        """
        model = MCPServer()
        if include_optional:
            return MCPServer(
                id = 56,
                platform = 56,
                name = '',
                url = '',
                transport = 'sse',
                headers = None,
                platform_key = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return MCPServer(
                id = 56,
                platform = 56,
                name = '',
                url = '',
                platform_key = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testMCPServer(self):
        """Test MCPServer"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from iblai.models.greeting_method_enum import GreetingMethodEnum
from typing import Optional, Set
from typing_extensions import Self

class MentorSettingsRequest(BaseModel):
    """
    MentorSettingsRequest
    """ # noqa: E501
    mentor_name: Optional[StrictStr] = None
    template_name: Optional[StrictStr] = None
    display_name: Optional[StrictStr] = None
    profile_image: Optional[StrictStr] = None
    initial_message: Optional[StrictStr] = None
    suggested_message: Optional[StrictStr] = None
    theme: Optional[StrictStr] = None
    user_message_color: Optional[StrictStr] = None
    mentor_bubble_color: Optional[StrictStr] = None
    align_mentor_bubble: Optional[StrictStr] = None
    system_prompt: Optional[StrictStr] = None
    llm_provider: Optional[StrictStr] = None
    llm_name: Optional[StrictStr] = None
    featured: Optional[StrictBool] = None
    disable_chathistory: Optional[StrictBool] = None
    metadata: Optional[Any] = None
    custom_css: Optional[StrictStr] = None
    department_id: Optional[StrictInt] = Field(default=None, description="Department to authorize users by")
    mentor_visibility: Optional[StrictStr] = None
    enable_image_generation: Optional[StrictBool] = None
    enable_web_browsing: Optional[StrictBool] = None
    enable_code_interpreter: Optional[StrictBool] = None
    allow_anonymous: Optional[StrictBool] = None
    forkable: Optional[StrictBool] = None
    forkable_with_training_data: Optional[StrictBool] = None
    mentor_description: Optional[StrictStr] = None
    uploaded_profile_image: Optional[StrictStr] = None
    proactive_response: Optional[StrictStr] = None
    greeting_method: Optional[GreetingMethodEnum] = None
    can_use_tools: Optional[StrictBool] = None
    tool_slugs: Optional[List[StrictStr]] = None
    llm_temperature: Optional[Union[Annotated[float, Field(le=1.0, strict=True, ge=0.0)], Annotated[int, Field(le=1, strict=True, ge=0)]]] = None
    proactive_prompt: Optional[StrictStr] = None
    moderation_system_prompt: Optional[StrictStr] = None
    post_processing_prompt: Optional[StrictStr] = None
    moderation_response: Optional[StrictStr] = None
    enable_moderation: Optional[StrictBool] = None
    enable_post_processing_system: Optional[StrictBool] = None
    enable_openai_assistant: Optional[StrictBool] = None
    enable_total_grounding: Optional[StrictBool] = None
    enable_suggested_prompts: Optional[StrictBool] = None
    enable_guided_prompts: Optional[StrictBool] = None
    mcp_servers: Optional[List[StrictInt]] = None
    google_voice: Optional[StrictInt] = None
    openai_voice: Optional[StrictInt] = None
    guided_prompt_instructions: Optional[StrictStr] = None
    safety_system_prompt: Optional[StrictStr] = None
    safety_response: Optional[StrictStr] = None
    enable_safety_system: Optional[StrictBool] = None
    enable_memory_component: Optional[StrictBool] = False
    enable_spaced_repetition: Optional[StrictBool] = False
    enable_instruction_mode: Optional[StrictBool] = False
    enable_socratic_mode: Optional[StrictBool] = False
    is_guided_mentor: Optional[StrictBool] = False
    enable_email_chat: Optional[StrictBool] = False
    categories: Optional[List[StrictInt]] = None
    __properties: ClassVar[List[str]] = ["mentor_name", "template_name", "display_name", "profile_image", "initial_message", "suggested_message", "theme", "user_message_color", "mentor_bubble_color", "align_mentor_bubble", "system_prompt", "llm_provider", "llm_name", "featured", "disable_chathistory", "metadata", "custom_css", "department_id", "mentor_visibility", "enable_image_generation", "enable_web_browsing", "enable_code_interpreter", "allow_anonymous", "forkable", "forkable_with_training_data", "mentor_description", "uploaded_profile_image", "proactive_response", "greeting_method", "can_use_tools", "tool_slugs", "llm_temperature", "proactive_prompt", "moderation_system_prompt", "post_processing_prompt", "moderation_response", "enable_moderation", "enable_post_processing_system", "enable_openai_assistant", "enable_total_grounding", "enable_suggested_prompts", "enable_guided_prompts", "mcp_servers", "google_voice", "openai_voice", "guided_prompt_instructions", "safety_system_prompt", "safety_response", "enable_safety_system", "enable_memory_component", "enable_spaced_repetition", "enable_instruction_mode", "enable_socratic_mode", "is_guided_mentor", "enable_email_chat", "categories"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MentorSettingsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if initial_message (nullable) is None
        # and model_fields_set contains the field
        if self.initial_message is None and "initial_message" in self.model_fields_set:
            _dict['initial_message'] = None

        # set to None if suggested_message (nullable) is None
        # and model_fields_set contains the field
        if self.suggested_message is None and "suggested_message" in self.model_fields_set:
            _dict['suggested_message'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if custom_css (nullable) is None
        # and model_fields_set contains the field
        if self.custom_css is None and "custom_css" in self.model_fields_set:
            _dict['custom_css'] = None

        # set to None if department_id (nullable) is None
        # and model_fields_set contains the field
        if self.department_id is None and "department_id" in self.model_fields_set:
            _dict['department_id'] = None

        # set to None if enable_suggested_prompts (nullable) is None
        # and model_fields_set contains the field
        if self.enable_suggested_prompts is None and "enable_suggested_prompts" in self.model_fields_set:
            _dict['enable_suggested_prompts'] = None

        # set to None if enable_guided_prompts (nullable) is None
        # and model_fields_set contains the field
        if self.enable_guided_prompts is None and "enable_guided_prompts" in self.model_fields_set:
            _dict['enable_guided_prompts'] = None

        # set to None if mcp_servers (nullable) is None
        # and model_fields_set contains the field
        if self.mcp_servers is None and "mcp_servers" in self.model_fields_set:
            _dict['mcp_servers'] = None

        # set to None if guided_prompt_instructions (nullable) is None
        # and model_fields_set contains the field
        if self.guided_prompt_instructions is None and "guided_prompt_instructions" in self.model_fields_set:
            _dict['guided_prompt_instructions'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MentorSettingsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "mentor_name": obj.get("mentor_name"),
            "template_name": obj.get("template_name"),
            "display_name": obj.get("display_name"),
            "profile_image": obj.get("profile_image"),
            "initial_message": obj.get("initial_message"),
            "suggested_message": obj.get("suggested_message"),
            "theme": obj.get("theme"),
            "user_message_color": obj.get("user_message_color"),
            "mentor_bubble_color": obj.get("mentor_bubble_color"),
            "align_mentor_bubble": obj.get("align_mentor_bubble"),
            "system_prompt": obj.get("system_prompt"),
            "llm_provider": obj.get("llm_provider"),
            "llm_name": obj.get("llm_name"),
            "featured": obj.get("featured"),
            "disable_chathistory": obj.get("disable_chathistory"),
            "metadata": obj.get("metadata"),
            "custom_css": obj.get("custom_css"),
            "department_id": obj.get("department_id"),
            "mentor_visibility": obj.get("mentor_visibility"),
            "enable_image_generation": obj.get("enable_image_generation"),
            "enable_web_browsing": obj.get("enable_web_browsing"),
            "enable_code_interpreter": obj.get("enable_code_interpreter"),
            "allow_anonymous": obj.get("allow_anonymous"),
            "forkable": obj.get("forkable"),
            "forkable_with_training_data": obj.get("forkable_with_training_data"),
            "mentor_description": obj.get("mentor_description"),
            "uploaded_profile_image": obj.get("uploaded_profile_image"),
            "proactive_response": obj.get("proactive_response"),
            "greeting_method": obj.get("greeting_method"),
            "can_use_tools": obj.get("can_use_tools"),
            "tool_slugs": obj.get("tool_slugs"),
            "llm_temperature": obj.get("llm_temperature"),
            "proactive_prompt": obj.get("proactive_prompt"),
            "moderation_system_prompt": obj.get("moderation_system_prompt"),
            "post_processing_prompt": obj.get("post_processing_prompt"),
            "moderation_response": obj.get("moderation_response"),
            "enable_moderation": obj.get("enable_moderation"),
            "enable_post_processing_system": obj.get("enable_post_processing_system"),
            "enable_openai_assistant": obj.get("enable_openai_assistant"),
            "enable_total_grounding": obj.get("enable_total_grounding"),
            "enable_suggested_prompts": obj.get("enable_suggested_prompts"),
            "enable_guided_prompts": obj.get("enable_guided_prompts"),
            "mcp_servers": obj.get("mcp_servers"),
            "google_voice": obj.get("google_voice"),
            "openai_voice": obj.get("openai_voice"),
            "guided_prompt_instructions": obj.get("guided_prompt_instructions"),
            "safety_system_prompt": obj.get("safety_system_prompt"),
            "safety_response": obj.get("safety_response"),
            "enable_safety_system": obj.get("enable_safety_system"),
            "enable_memory_component": obj.get("enable_memory_component") if obj.get("enable_memory_component") is not None else False,
            "enable_spaced_repetition": obj.get("enable_spaced_repetition") if obj.get("enable_spaced_repetition") is not None else False,
            "enable_instruction_mode": obj.get("enable_instruction_mode") if obj.get("enable_instruction_mode") is not None else False,
            "enable_socratic_mode": obj.get("enable_socratic_mode") if obj.get("enable_socratic_mode") is not None else False,
            "is_guided_mentor": obj.get("is_guided_mentor") if obj.get("is_guided_mentor") is not None else False,
            "enable_email_chat": obj.get("enable_email_chat") if obj.get("enable_email_chat") is not None else False,
            "categories": obj.get("categories")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from iblai.models.retriever_document_embedding_access import RetrieverDocumentEmbeddingAccess
from iblai.models.retriever_document_embedding_training_status import RetrieverDocumentEmbeddingTrainingStatus
from typing import Optional, Set
from typing_extensions import Self

class RetrieverDocumentEmbedding(BaseModel):
    """
    RetrieverDocumentEmbedding
    """ # noqa: E501
    id: StrictInt
    metadata: Optional[Any] = None
    document_name: Optional[StrictStr] = None
    document_type: Optional[StrictStr] = None
    training_status: Optional[RetrieverDocumentEmbeddingTrainingStatus] = None
    pathway: StrictStr
    url: Optional[StrictStr] = None
    tokens: Optional[StrictInt] = None
    platform_key: StrictStr
    is_trained: Optional[StrictBool] = None
    access: Optional[RetrieverDocumentEmbeddingAccess] = None
    __properties: ClassVar[List[str]] = ["id", "metadata", "document_name", "document_type", "training_status", "pathway", "url", "tokens", "platform_key", "is_trained", "access"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RetrieverDocumentEmbedding from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of training_status
        if self.training_status:
            _dict['training_status'] = self.training_status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of access
        if self.access:
            _dict['access'] = self.access.to_dict()
        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if document_name (nullable) is None
        # and model_fields_set contains the field
        if self.document_name is None and "document_name" in self.model_fields_set:
            _dict['document_name'] = None

        # set to None if document_type (nullable) is None
        # and model_fields_set contains the field
        if self.document_type is None and "document_type" in self.model_fields_set:
            _dict['document_type'] = None

        # set to None if training_status (nullable) is None
        # and model_fields_set contains the field
        if self.training_status is None and "training_status" in self.model_fields_set:
            _dict['training_status'] = None

        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        # set to None if tokens (nullable) is None
        # and model_fields_set contains the field
        if self.tokens is None and "tokens" in self.model_fields_set:
            _dict['tokens'] = None

        # set to None if access (nullable) is None
        # and model_fields_set contains the field
        if self.access is None and "access" in self.model_fields_set:
            _dict['access'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RetrieverDocumentEmbedding from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "metadata": obj.get("metadata"),
            "document_name": obj.get("document_name"),
            "document_type": obj.get("document_type"),
            "training_status": RetrieverDocumentEmbeddingTrainingStatus.from_dict(obj["training_status"]) if obj.get("training_status") is not None else None,
            "pathway": obj.get("pathway"),
            "url": obj.get("url"),
            "tokens": obj.get("tokens"),
            "platform_key": obj.get("platform_key"),
            "is_trained": obj.get("is_trained"),
            "access": RetrieverDocumentEmbeddingAccess.from_dict(obj["access"]) if obj.get("access") is not None else None
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_bot_api import AiBotApi


class TestAiBotApi(unittest.TestCase):
    """AiBotApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiBotApi()

    def tearDown(self) -> None:
        pass

    def test_ai_bot_v1_bots_bot_commands_create(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_create

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_destroy

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_list(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_list

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_partial_update

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_retrieve

        """
        pass

    def test_ai_bot_v1_bots_bot_commands_update(self) -> None:
        """Test case for ai_bot_v1_bots_bot_commands_update

        """
        pass

    def test_ai_bot_v1_bots_bot_create(self) -> None:
        """Test case for ai_bot_v1_bots_bot_create

        """
        pass

    def test_ai_bot_v1_bots_bot_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_bot_destroy

        """
        pass

    def test_ai_bot_v1_bots_bot_list(self) -> None:
        """Test case for ai_bot_v1_bots_bot_list

        """
        pass

    def test_ai_bot_v1_bots_bot_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_bot_partial_update

        """
        pass

    def test_ai_bot_v1_bots_bot_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_bot_retrieve

        """
        pass

    def test_ai_bot_v1_bots_bot_update(self) -> None:
        """Test case for ai_bot_v1_bots_bot_update

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_create(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_create

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_destroy

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_list(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_list

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_partial_update

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_retrieve

        """
        pass

    def test_ai_bot_v1_bots_discord_user_config_update(self) -> None:
        """Test case for ai_bot_v1_bots_discord_user_config_update

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_create(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_create

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_destroy

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_list(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_list

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_partial_update

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_retrieve

        """
        pass

    def test_ai_bot_v1_bots_slack_user_config_update(self) -> None:
        """Test case for ai_bot_v1_bots_slack_user_config_update

        """
        pass

    def test_ai_bot_v1_bots_webhooks_discord_create(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_discord_create

        """
        pass

    def test_ai_bot_v1_bots_webhooks_slack_create(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_slack_create

        """
        pass

    def test_ai_bot_v1_bots_webhooks_webex_create(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_webex_create

        """
        pass

    def test_ai_bot_v1_bots_webhooks_whatsapp_create(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_whatsapp_create

        """
        pass

    def test_ai_bot_v1_bots_webhooks_whatsapp_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_webhooks_whatsapp_retrieve

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_create(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_create

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_destroy(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_destroy

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_list(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_list

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_partial_update(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_partial_update

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_retrieve(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_retrieve

        """
        pass

    def test_ai_bot_v1_bots_whatsapp_user_config_update(self) -> None:
        """Test case for ai_bot_v1_bots_whatsapp_user_config_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
